const { join, relative } = require('path')
const globby = require('globby')

module.exports = async function (nuxt, builder) {
  const { options, resolver } = nuxt

  const pluginsDir = join(options.srcDir, options.dir.plugins || 'plugins')

  // Scan plugins/*.js
  let plugins = await globby(pluginsDir, '**/*.js')

  // Resolve aliases
  plugins = plugins.map(p => resolver.resolveAlias(p))

  // Filter duplicates
  plugins = plugins.filter((p) => {
    const found = options.plugins.find(_p => p === resolver.resolveAlias(_p.src || _p))
    return !found
  })

  // Filter ignored (from .nuxtignore)
  plugins = builder.ignore.filter(plugins.map(p => relative(builder.ignore.rootDir, p)))
  plugins = plugins.map(p => join(builder.ignore.rootDir, p))

  // Append plugins
  options.plugins = [
    ...options.plugins,
    ...plugins
  ]
}
